var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var EventDispatcher = require('../event/EventDispatcher');
var TransitionFactory = require('../util/TransitionFactory');
var TransitionType = require('../constant/TransitionType');
var TransitionManagerEvent = require('../event/TransitionManagerEvent');
var TweenEvent = require('../event/TweenEvent');
/**
 * TODO: YUIDoc_comment
 *
 * @class TransitionManager
 * @extends EventDispatcher
 * @constructor
 * @author Robert S. (www.codeBelt.com)
 */
var TransitionManager = (function (_super) {
    __extends(TransitionManager, _super);
    function TransitionManager(displayContainer) {
        _super.call(this);
        this._viewContainer = null;
        this._currentView = null;
        this._nextView = null;
        this._state = TransitionManager.READY;
        this._transitionFactory = new TransitionFactory();
        this._runningTransition = null;
        this._viewContainer = displayContainer;
    }
    TransitionManager.prototype.getCurrentView = function () {
        return this._currentView;
    };
    TransitionManager.prototype.getSectionStage = function () {
        return this._viewContainer;
    };
    TransitionManager.prototype.setTransitionContainer = function (displayContainer) {
        this._viewContainer = displayContainer;
        return this;
    };
    TransitionManager.prototype.isTransitioning = function () {
        return this._state != TransitionManager.READY;
    };
    TransitionManager.prototype.getState = function () {
        return this._state;
    };
    TransitionManager.prototype.registerTransition = function (key, transitionFactory) {
        this._transitionFactory.registerTransition(key, transitionFactory);
        return this;
    };
    TransitionManager.prototype.setCurrentView = function (currentView) {
        this._currentView = currentView;
        this._viewContainer.addChild(this._currentView);
        this._currentView.enable();
        return this;
    };
    /**
     * @overridden EventDispatcher.destroy
     */
    TransitionManager.prototype.destroy = function () {
        this._transitionFactory.destroy();
        _super.prototype.destroy.call(this);
    };
    TransitionManager.prototype.removeCurrentView = function () {
        if (this._currentView === null) {
            return;
        }
        this._viewContainer.removeChild(this._currentView);
        this._currentView.destroy();
        this._currentView = this._nextView;
        this._nextView = null;
    };
    TransitionManager.prototype.transitionToNextView = function (nextView, transitionType, transitionDuration) {
        if (transitionType === void 0) { transitionType = TransitionType.NONE; }
        if (transitionDuration === void 0) { transitionDuration = -1; }
        // If the current view is not set then throw an error.
        if (this._currentView === null) {
            throw new Error('[' + this.getQualifiedClassName() + '] The current view must be set before attempting to transition to another view. See the setCurrentView method');
        }
        // If the transition is running then complete right away so we can start the next one.
        if (this.isTransitioning()) {
            this._runningTransition.complete();
        }
        // Assign the next view and add it to the reference view container.
        this._nextView = nextView;
        this._viewContainer.addChild(this._nextView);
        this._nextView.enable();
        // Create the transition and listen for events.
        this._runningTransition = this._transitionFactory.createTransition(transitionType, this._viewContainer, this._currentView, this._nextView, transitionDuration);
        this._runningTransition.addEventListener(TweenEvent.START, this.onTransitionStart, this);
        //this._runningTransition.addEventListener(TweenEvent.UPDATE, this.onTransitionUpdate, this);
        this._runningTransition.addEventListener(TweenEvent.COMPLETE, this.onTransitionComplete, this);
        this._state = TransitionManager.TRANSITION_RUNNING;
        return this;
    };
    TransitionManager.prototype.onTransitionStart = function (event) {
        this.dispatchEvent(new TransitionManagerEvent(TransitionManagerEvent.TRANSITION_START));
    };
    TransitionManager.prototype.onTransitionUpdate = function (event) {
    };
    TransitionManager.prototype.onTransitionComplete = function (event) {
        if (this._currentView) {
            this.removeCurrentView();
        }
        if (this._runningTransition != null) {
            this._runningTransition.removeEventListener(TweenEvent.START, this.onTransitionStart, this);
            this._runningTransition.removeEventListener(TweenEvent.COMPLETE, this.onTransitionComplete, this);
            this._runningTransition = null;
        }
        this._state = TransitionManager.READY;
        this.dispatchEvent(new TransitionManagerEvent(TransitionManagerEvent.TRANSITION_COMPLETE));
    };
    TransitionManager.READY = 'ready';
    TransitionManager.TRANSITION_RUNNING = 'transitionRunning';
    return TransitionManager;
})(EventDispatcher);
module.exports = TransitionManager;
//# sourceMappingURL=TransitionManager.js.map