var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var EventDispatcher = require('../../event/EventDispatcher');
var TweenEvent = require('../../event/TweenEvent');
var BaseTransition = (function (_super) {
    __extends(BaseTransition, _super);
    /**
     * TODO: YUIDoc_comment
     *
     * @class BaseTransition
     * @extends EventDispatcher
     * @module StructureJS
     * @submodule controller
     * @constructor
     * @author Robert S. (www.codeBelt.com)
     * @version 0.1.0
     */
    function BaseTransition() {
        _super.call(this);
        /**
         * Property of the TimelineMax object.
         *
         * @property transition
         * @type {TimelineMax}
         * @readOnly
         */
        this.transition = null;
    }
    /**
     * Creates and starts the transition for the specific transition type.
     *
     * @method createTransition
     * @param transitionType {string)
     * @param viewContainer {DisplayObjectContainer)
     * @param currentView {DOMElement)
     * @param nextView {DOMElement)
     * @param [duration=0.75] {number)
     * @returns {ITransition}
     */
    BaseTransition.prototype.createTransition = function (transitionType, viewContainer, currentView, nextView, duration) {
        if (duration === void 0) { duration = 0.75; }
        return this;
    };
    /**
     * Gets called by the TimelineMax object when the transition starts. Dispatches the TweenEvent.START event. The data value of the TweenEvent event is set to the TimelineMax object.
     *
     * @method onTweenStart
     * @returns {BaseTransition}
     * @protected
     * @chainable
     */
    BaseTransition.prototype.onTweenStart = function () {
        this.dispatchEvent(new TweenEvent(TweenEvent.START, false, false, this.transition));
        return this;
    };
    /**
     * Gets called by the TimelineMax object every time the timeline updates (on every frame while the timeline is active). Dispatches the TweenEvent.START event. The data value of the TweenEvent event is set to the TimelineMax object.
     *
     * @method onTweenUpdate
     * @returns {BaseTransition}
     * @protected
     * @chainable
     */
    BaseTransition.prototype.onTweenUpdate = function () {
        this.dispatchEvent(new TweenEvent(TweenEvent.UPDATE, false, false, this.transition));
        return this;
    };
    /**
     * Gets called by the TimelineMax object when the transition completes. Dispatches the TweenEvent.COMPLETE event. The data value of the TweenEvent event is set to the TimelineMax object.
     *
     * @method onTweenComplete
     * @returns {BaseTransition}
     * @protected
     * @chainable
     */
    BaseTransition.prototype.onTweenComplete = function () {
        this.dispatchEvent(new TweenEvent(TweenEvent.COMPLETE, false, false, this.transition));
        return this;
    };
    /**
     * Tells TimelineMax to finishes/complete the transition right away.
     *
     * @method complete
     * @returns {BaseTransition}
     * @chainable
     */
    BaseTransition.prototype.complete = function () {
        this.transition.progress(1);
        return this;
    };
    /**
     * @overridden EventDispatcher.destroy
     */
    BaseTransition.prototype.destroy = function () {
        this.complete();
        _super.prototype.destroy.call(this);
    };
    return BaseTransition;
})(EventDispatcher);
module.exports = BaseTransition;
//# sourceMappingURL=BaseTransition.js.map