var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var BaseEvent = require('./BaseEvent');
/**
 * The LanguageEvent...
 *
 * @class LanguageEvent
 * @extends BaseEvent
 * @param type {string} The type of event. The type is case-sensitive.
 * @param [bubbles=false] {boolean} Indicates whether an event is a bubbling event. If the event can bubble, this value is true; otherwise it is false.
 * Note: With event-bubbling you can let one Event subsequently call on every ancestor ({{#crossLink "EventDispatcher/parent:property"}}{{/crossLink}})
 * (containers of containers of etc.) of the {{#crossLink "DisplayObjectContainer"}}{{/crossLink}} that originally dispatched the Event, all the way up to the surface ({{#crossLink "Stage"}}{{/crossLink}}). Any classes that do not have a parent cannot bubble.
 * @param [cancelable=false] {boolean} Indicates whether the behavior associated with the event can be prevented. If the behavior can be canceled, this value is true; otherwise it is false.
 * @param [data=null] {any} Use to pass any type of data with the event.
 * @module StructureJS
 * @submodule event
 * @constructor
 * @author Robert S. (www.codeBelt.com)
 */
var LanguageEvent = (function (_super) {
    __extends(LanguageEvent, _super);
    function LanguageEvent(type, bubbles, cancelable, data) {
        if (bubbles === void 0) { bubbles = false; }
        if (cancelable === void 0) { cancelable = false; }
        if (data === void 0) { data = null; }
        _super.call(this, type, bubbles, cancelable, data);
    }
    /**
     * TODO: YUIDoc_comment
     *
     * @event CONFIG_LOADED
     * @type {string}
     * @static
     */
    LanguageEvent.CONFIG_LOADED = "LanguageEvent.configLoaded";
    /**
     * TODO: YUIDoc_comment
     *
     * @event LOAD_COMPLETE
     * @type {string}
     * @static
     */
    LanguageEvent.LANGUAGE_LOADED = "LanguageEvent.languageLoaded";
    /**
     * TODO: YUIDoc_comment
     *
     * @event LANGUAGE_CHANGE
     * @type {string}
     * @static
     */
    LanguageEvent.LANGUAGE_CHANGE = "LanguageEvent.languageChange";
    return LanguageEvent;
})(BaseEvent);
module.exports = LanguageEvent;
//# sourceMappingURL=LanguageEvent.js.map