var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var BaseObject = require('../BaseObject');
var URLRequestMethod = require('./URLRequestMethod');
var URLContentType = require('./URLContentType');
/**
 * The URLRequest class captures all of the information in a single HTTP request.
 * URLRequest objects are passed to the load() methods of the {{#crossLink "URLLoader"}}{{/crossLink}} classes.
 *
 * @class URLRequest
 * @extends BaseObject
 * @param url [string=null] The URL to be requested. You can set the URL later by using the url property.
 * @module StructureJS
 * @submodule net
 * @requires Extend
 * @requires BaseObject
 * @requires URLRequestMethod
 * @requires URLContentType
 * @constructor
 * @author Robert S. (www.codeBelt.com)
 */
var URLRequest = (function (_super) {
    __extends(URLRequest, _super);
    function URLRequest(url) {
        if (url === void 0) { url = null; }
        _super.call(this);
        /**
         * The URL to be requested.
         *
         * @property url
         * @type {string}
         * @public
         */
        this.url = null;
        /**
         * Controls the HTTP form submission method ({{#crossLink "URLRequestMethod"}}{{/crossLink}}).
         *
         * @property method
         * @type {string}
         * @default URLRequestMethod.GET
         * @public
         */
        this.method = URLRequestMethod.GET;
        /**
         * The MIME content type of the content in the the data property ({{#crossLink "URLContentType"}}{{/crossLink}}).
         *
         * @property method
         * @type {string}
         * @default application/x-www-form-urlencoded
         * @public
         */
        this.contentType = URLContentType.DEFAULT;
        /**
         * An object containing data to be transmitted with the URL request.
         *
         * @property data
         * @type {any}
         * @public
         */
        this.data = null;
        this.url = url;
    }
    return URLRequest;
})(BaseObject);
module.exports = URLRequest;
//# sourceMappingURL=URLRequest.js.map