var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var URLRequest = require('../net/URLRequest');
var URLLoader = require('../net/URLLoader');
var EventDispatcher = require('../event/EventDispatcher');
var RequestEvent = require('../event/RequestEvent');
var LoaderEvent = require('../event/LoaderEvent');
/**
 * The BaseRequest...
 *
 * @class BaseRequest
 * @module StructureJS
 * @submodule net
 * @constructor
 * @author Robert S. (www.codeBelt.com)
 */
var BaseRequest = (function (_super) {
    __extends(BaseRequest, _super);
    function BaseRequest(baseUrl, endpoint) {
        if (endpoint === void 0) { endpoint = ''; }
        _super.call(this);
        /**
         * TODO: YUIDoc_comment
         *
         * @property _baseUrl
         * @type {string}
         * @protected
         */
        this._baseUrl = null;
        /**
         * TODO: YUIDoc_comment
         *
         * @property _endpoint
         * @type {string}
         * @protected
         */
        this._endpoint = null;
        /**
         * TODO: YUIDoc_comment
         *
         * @property _request
         * @type {URLRequest}
         * @protected
         */
        this._request = null;
        /**
         * TODO: YUIDoc_comment
         *
         * @property _loader
         * @type {URLLoader}
         * @readonly
         * @protected
         */
        this._loader = null;
        /**
         * TODO: YUIDoc_comment
         *
         * @property data
         * @type {any}
         * @public
         */
        this.data = null;
        /**
         * TODO: YUIDoc_comment
         *
         * @property complete
         * @type {boolean}
         * @default false
         * @public
         */
        this.complete = false;
        /**
         * TODO: YUIDoc_comment
         *
         * @property src
         * @type {string}
         * @public
         */
        this.src = null;
        this._baseUrl = baseUrl;
        this._endpoint = endpoint;
    }
    /**
     * TODO: YUIDoc_comment
     *
     * @method getloader
     * @public
     */
    BaseRequest.prototype.getloader = function () {
        return this._loader;
    };
    /* ---------------------------------------------------------------------
     Protected Methods
     ------------------------------------------------------------------------ */
    /**
     * TODO: YUIDoc_comment
     *
     * @method configureRequest
     * @return {URLRequest}
     * @protected
     */
    BaseRequest.prototype.configureRequest = function () {
        this.src = this._baseUrl + this._endpoint;
        this._request = new URLRequest(this.src);
        return this._request;
    };
    /**
     * TODO: YUIDoc_comment
     *
     * @method load
     * @protected
     */
    BaseRequest.prototype.load = function () {
        this.complete = false;
        this._loader = new URLLoader();
        this._loader.addEventListener(LoaderEvent.COMPLETE, this.onDataLoadComplete, this);
        this._loader.addEventListener(LoaderEvent.ERROR, this.onDataLoadError, this);
        if (this._request) {
            this._loader.load(this._request);
        }
        else {
            throw new Error('[' + this.getQualifiedClassName() + '] Error: No request object created for proxy. Override configureRequest');
        }
    };
    /**
     * TODO: YUIDoc_comment
     *
     * @method parseData
     * @protected
     */
    BaseRequest.prototype.parseData = function () {
        this.data = this._loader.data;
    };
    /**
     * TODO: YUIDoc_comment
     *
     * @method cleanupListeners
     * @protected
     */
    BaseRequest.prototype.cleanupListeners = function () {
        this._loader.removeEventListener(LoaderEvent.COMPLETE, this.onDataLoadComplete, this);
        this._loader.removeEventListener(LoaderEvent.ERROR, this.onDataLoadError, this);
    };
    /**
     * TODO: YUIDoc_comment
     *
     * @method onDataLoadComplete
     * @param event {LoaderEvent}
     * @protected
     */
    BaseRequest.prototype.onDataLoadComplete = function (event) {
        this.parseData();
        this.complete = true;
        this.cleanupListeners();
        this.dispatchEvent(new RequestEvent(RequestEvent.SUCCESS, false, false, this.data));
    };
    /**
     * TODO: YUIDoc_comment
     *
     * @method onDataLoadComplete
     * @param event {LoaderEvent}
     * @protected
     */
    BaseRequest.prototype.onDataLoadError = function (event) {
        this.cleanupListeners();
        this.dispatchEvent(new RequestEvent(RequestEvent.ERROR, false, false, this.data));
    };
    /**
     * @overridden EventDispatcher.destroy
     */
    BaseRequest.prototype.destroy = function () {
        this._loader.destroy();
        _super.prototype.destroy.call(this);
    };
    return BaseRequest;
})(EventDispatcher);
module.exports = BaseRequest;
//# sourceMappingURL=BaseRequest.js.map