var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var BaseObject = require('../BaseObject');
var TransitionType = require('../constant/TransitionType');
var TransitionNone = require('../controller/transition/TransitionNone');
var TransitionPushLeft = require('../controller/transition/TransitionPushLeft');
var TransitionPushRight = require('../controller/transition/TransitionPushRight');
var TransitionPushUp = require('../controller/transition/TransitionPushUp');
var TransitionPushDown = require('../controller/transition/TransitionPushDown');
var TransitionCrossFade = require('../controller/transition/TransitionCrossFade');
var TransitionFadeOutAndIn = require('../controller/transition/TransitionFadeOutAndIn');
/**
 * TODO: YUIDoc_comment
 *
 * @class TransitionFactory
 * @module StructureJS
 * @submodule util
 * @constructor
 * @author Robert S. (www.codeBelt.com)
 */
var TransitionFactory = (function (_super) {
    __extends(TransitionFactory, _super);
    function TransitionFactory() {
        _super.call(this);
        /**
         * TODO: YUIDoc_comment
         *
         * @property _transitions
         * @type {Object}
         * @protected
         */
        this._transitions = {};
        this.registerTransition(TransitionType.NONE, new TransitionNone());
        this.registerTransition(TransitionType.PUSH_LEFT, new TransitionPushLeft());
        this.registerTransition(TransitionType.PUSH_RIGHT, new TransitionPushRight());
        this.registerTransition(TransitionType.PUSH_UP, new TransitionPushUp());
        this.registerTransition(TransitionType.PUSH_DOWN, new TransitionPushDown());
        this.registerTransition(TransitionType.CROSSFADE, new TransitionCrossFade());
        this.registerTransition(TransitionType.FADE_OUT_AND_IN, new TransitionFadeOutAndIn());
    }
    /**
     * TODO: YUIDoc_comment
     *
     * @param transitionType {string}
     * @param sectionStage {DisplayObjectContainer}
     * @param currentView {DOMElement}
     * @param nextView {DOMElement}
     * @param duration {number}
     * @returns {ITransition}
     */
    TransitionFactory.prototype.createTransition = function (transitionType, sectionStage, currentView, nextView, duration) {
        if (duration === void 0) { duration = -1; }
        var concreteFactory = this._transitions[transitionType];
        if (concreteFactory == null) {
            throw new Error('[' + this.getQualifiedClassName() + '] Not found factory for type: ' + transitionType);
        }
        if (duration >= 0) {
            return concreteFactory.createTransition(transitionType, sectionStage, currentView, nextView, duration);
        }
        else {
            return concreteFactory.createTransition(transitionType, sectionStage, currentView, nextView);
        }
    };
    /**
     * The registerTransition method allows you to add custom transitions to the {{#crossLink "TransitionFactory"}}{{/crossLink}}.
     *
     * @method registerTransition
     * @param key {string} The key value for the transition being passed in.
     * @param transitionFactory{ITransition} A transition that implements {{#crossLink "ITransition"}}{{/crossLink}}.
     * @chainable
     * @public
     */
    TransitionFactory.prototype.registerTransition = function (key, transitionFactory) {
        if (this._transitions.hasOwnProperty(key)) {
            throw new Error('[' + this.getQualifiedClassName() + '] A transition with that key has already been registered.');
        }
        this._transitions[key] = transitionFactory;
        return this;
    };
    /**
     * @overridden BaseObject.destroy
     */
    TransitionFactory.prototype.destroy = function () {
        _super.prototype.destroy.call(this);
    };
    return TransitionFactory;
})(BaseObject);
module.exports = TransitionFactory;
//# sourceMappingURL=TransitionFactory.js.map